/*
 * Copyright 2011 Gewton Jhames <gewtonj@gmail.com>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.gewton.slsecurity.service;

import java.util.List;

import info.gewton.slsecurity.model.Post;
import info.gewton.slsecurity.model.PostUser;

/**
 * Interface de Service para {@link Post}. Em uma situação real, poderíamos
 * ter uma interface mais genérica <tt>CrudService</tt>, que definiria tais 
 * métodos, e <tt>PostService</tt> extenderia <tt>CrudService</tt>, adicionando 
 * seus métodos particulares.
 * @author gewton
 */
public interface PostService {
    /**
     * Cria um novo {@link Post}. <br />
     * Somente usuários que possuem o papel ROLE_POSTER e ROLE_SUPERUSER podem postar. <br />
     * Somente ROLE_SUPERUSER podem postar textos com mais de 140 caracteres. <br />
     * O usuário do sistema que está postando deverá ser o mesmo do parâmetro
     * <tt>username</tt>.
     * @param text o conteúdo
     * @param username o <tt>username</tt> do post. O usuário do sistema que está
     * postando deverá ser o mesmo deste parâmetro
     */
    void post(String text, String username);
    /**
     * Recuperar posts de um determinado {@link PostUser}.
     * @param u usuário que postou os {@link Post}s que serão retornados
     * @return lista de {@link Post} postados por <tt>u</tt>
     */
    List<Post> retrievePosts(PostUser u);
    /**
     * Remover um {@link Post}. Somente usuários com o papel ROLE_ADMIN.
     * @param p {@link Post} a ser removido
     */
    void unpost(Post p);
    
    /**
     * Executa a operação secreta número 1. Somente usuários ROLE_SECRET poderão
     * ter acesso a este método
     */
    void oneSecretOperation();

    /**
     * Executa a operação secreta número 2. Somente usuários ROLE_SECRET poderão
     * ter acesso a este método
     */
    void twoSecretOperation();
    
    /**
     * Executa a operação secreta número 3. Somente usuários ROLE_SECRET poderão
     * ter acesso a este método
     */
    void threeSecretOperation();
}
