/*
 * Copyright 2011 Gewton Jhames <gewtonj@gmail.com>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.gewton.slsecurity.service.support;

import info.gewton.slsecurity.dao.support.PostDao;
import info.gewton.slsecurity.model.Post;
import info.gewton.slsecurity.model.PostUser;
import info.gewton.slsecurity.service.PostService;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Service;

/**
 * Estratégia padrão para {@link PostService}.
 * @author gewton
 */
@Service
public class DefaultPostService implements PostService {

    protected Logger log = LoggerFactory.getLogger(DefaultPostService.class);
    
    @Autowired
    private PostDao dao;
    
    @PreAuthorize("((hasRole('ROLE_POSTER') and #text.length() <= 140) or hasRole('ROLE_SUPERUSER')) and authentication.name == #username")
    public void post(String text, String username) {
        Post p = new Post();
        p.setText(text);
        p.setTimestamp(new Date());
        p.setUser(new PostUser(username));
        dao.add(p);
    }

    @Secured({"ROLE_POSTER", "ROLE_SUPERUSER", "ROLE_ADMIN"})
    public List<Post> retrievePosts(PostUser u) {
        return dao.retrieveByUser(u);
    }

    @Secured("ROLE_ADMIN")
    public void unpost(Post p) {
        dao.delete(p);
    }
    
    public void oneSecretOperation() {
        log.info("oneSecretOperation invocada");
    }
    
    public void twoSecretOperation() {
        log.info("twoSecretOperation invocada");
    }
    
    public void threeSecretOperation() {
        log.info("threeSecretOperation invocada");
    }

}
