/*
 * Copyright 2011 Gewton Jhames <gewtonj@gmail.com>
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.gewton.slsecurity.test.simpletestcases;

import info.gewton.slsecurity.model.Post;
import info.gewton.slsecurity.model.PostUser;
import info.gewton.slsecurity.service.PostService;
import info.gewton.slsecurity.test.Test;

import java.util.List;

/**
 * Simples teste de remoção de Post. Somente usuários ROLE_ADMIN podem realizar
 * essa operação. <br />
 * Efetua login com o usuário <tt>adama</tt> e remove um Post do usuário <tt>apollo</tt>.
 * @author gewton
 */
public class RemoverPostTest extends Test {
    
    public static void main(String[] args) {
        new RemoverPostTest().doTest();
    }

    public void doTest() {
        // ~ Levanta o contexto e efetua login ==================================
        loadApplicationContext();
        setSecurityContext("adama", "adama");
        // ~ Recupera a classe da Service Layer =================================
        PostService s = getAc().getBean(PostService.class);
        // ~ Informa a quantidade de posts desse usuário ========================
        List<Post> posts = s.retrievePosts(new PostUser("apollo"));
        log.info("Tamanho inicial: " + posts.size());
        // ~ Remove o primeiro post da lista ====================================
        Post post = posts.get(0);
        log.info("Removendo primeiro post encontrado. Id " + post.getId());
        s.unpost(post);
        // ~ Informa a nova quantidade de posts desse usuário ===================
        log.info("Recuperando os posts novamente");
        posts = s.retrievePosts(new PostUser("apollo"));
        log.info("Novo tamanho: " + posts.size());
    }
}
